@@ -5,9 +5,9 @@
   ver <- packageDescription("epiR", lib.loc = NULL, fields = "Version")
   cat(paste("epiR version", ver))
   cat("\n")
-  cat("An R package for the analysis of epidemiological data.")
+  cat("Tools for the Analysis of Epidemiological Data")
   cat("\n")
-  cat("See http://epicentre.massey.ac.nz/ for details.")
+  cat("See http://fvas.unimelb.edu.au/veam for details.")
   cat("\n")
   cat("-----------------------------------------------------------\n")
   invisible()
